#! /bin/sh
#  Installation script for 'symhisl' HBA driver
#  This script must be run as root user
#
#  This will perform the following actions:
#
#  copy driver(s) to /kernel/drv
#  copy driver configuration files to /kernel/drv
#  copy man page to /usr/share/man/man7d
#  change the owner of the driver files to root
#  change the group of the driver files to sys
#  change the protections of the driver files
#  update the /etc/devlink.tab file for the DMI interface ioctl
#  run add_drv(1M) to add drivers to the system, including:
#     - aliases appropriate for pci devices
#     - class of type 'scsi', to permit attaching scsi target drivers
#     - touches /reconfigure
#
#  Following installation, please reboot the machine to reconfigure it
#  properly

DST=/kernel/drv
BASE=`uname -p`
DEVLINKTB="/etc/devlink.tab"
TMP=/tmp/$$

# Chip     Device ID   Description
# 896      b           Dual-channel Ultra2 SCSI
# 895a     12          Single-channel Ultra2 SCSI
# 1010     20          Dual-channel Ultra3 SCSI w/33 MHz PCI
# 1010-66  21          Dual-channel Ultra3 SCSI w/66 MHz PCI

#  add_devlink - adds an entry for our DMI interface ioctl
#  First remove any lines from the devlink.tab file that may contain our
#  entry, then add our entry and finally overwrite the original file.
add_devlink()
{
    PATTERN="$1"
    LINK="$2"

    grep -v "^$PATTERN" ${DEVLINKTB} >$TMP.devlink
    echo "$PATTERN\t$LINK" >>$TMP.devlink
    mv $TMP.devlink ${DEVLINKTB}
}

# Add the symhisl driver
cp ./symhisl.cnf ${DST}/symhisl.conf
cp ./${BASE}/symhisl ${DST}
chown root:sys ${DST}/symhisl ${DST}/symhisl.conf
chmod 755 ${DST}/symhisl
chmod 744 ${DST}/symhisl.conf
cp ./symhisl.7d /usr/share/man/man7d/symhisl.7d
chown bin:bin /usr/share/man/man7d/symhisl.7d
chmod 444 /usr/share/man/man7d/symhisl.7d
add_drv -m" * 0666 root root" -i'"pci1000,b" "pci1000,12" "pci1000,20" "pci1000,21"' -c scsi symhisl

# Add the devlink
add_devlink 'type=symsl_ctl' 'symhislctl\N0'
echo "Following installation, please reboot the machine to reconfigure"

